==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: "Attiva Applicazione"

, "Disable Application"
: "Disattiva Applicazione"

, "Settings"
: "Impostazioni"

, "{0} Settings"
: "{0} Impostazioni"

, "Search:"
: "Cerca:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Visualizza applicazione {0} - {1} di {2}"

, "No applications to display"
: "Nessuna applicazione da visualizzare"

, "Order"
: "Ordine"

, "Name"
: "Nome"

, "Status"
: "Stato"

, "Version"
: "Versione"

, "Confirm"
: "Conferma"

, "Do you really want to delete the selected groups?"
: "Vuoi veramente cancellare il gruppo selezionato?"

, "Deleting group(s)..."
: "Cancellazione gruppo(i)..."

, "Failed"
: "Fallita"

, "Some error occurred while trying to delete the group."
: "Si sono verificati alcuni errori durante il tentativo di cancellazione del gruppo."

, "Add Group"
: "Aggiungi Gruppo"

, "Edit Group"
: "Modifica Gruppo"

, "Delete Group"
: "Cancella Gruppo"

, "Displaying groups {0} - {1} of {2}"
: "Visualizzazione gruppi {0} - {1} di {2}"

, "No groups to display"
: "Nessun gruppo da visualizzare"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Descrizione"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Errori"

, "Please configure store for this field type"
: "Si prega di configurare la memorizzazione per questo tipo di campo"

, "Application, Applications"
: [
  "Applicazione"
 ,"Applicazioni"

]
, "Record Class"
: "Record Classe"

, "Given record class not found"
: "Record classe non trovato"

, "Cancel"
: "Cancella"

, "OK"
: "OK"

, "Configure store"
: "Configurazione Memorizzazione"

, "Model"
: "Modello"

, "Custom field definition"
: "definizione di campo personalizzato"

, "Text"
: "Testo"

, "Textarea"
: ""

, "Number"
: "Numero"

, "Date"
: "Data"

, "DateTime"
: "Data e Ora"

, "Time"
: "Ora"

, "Boolean"
: "Booleano"

, "Search Combo"
: "Ricerca combinata"

, "Key Field"
: "Campo Chiave"

, "Record"
: "Dato"

, "Record List"
: ""

, "Type"
: "Tipo"

, "Label"
: "Etichetta"

, "Length"
: "Lunghezza"

, "Required"
: "Richiesto"

, "Custom field additional properties"
: "Proprietà dei campi personalizzati aggiuntivi"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Gruppo"
 ,"Gruppi"

]
, "Customfield already exists. Please choose another name."
: "Campo personalizzato già esistente. Scegli un altro nome."

, "Customfield, Customfields"
: [
  "campo personalizzato"
 ,"campi personalizzati"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Valore"

, "Default ({0})"
: ""

, "Computer Name"
: "Nome Computer"

, "Default Addressbook for new contacts and groups"
: "Rubrica di default per i nuovi contatti e gruppi"

, "Please wait"
: "Attendi"

, "Updating Tag"
: "Aggiornamento Tag"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Si prega di correggere gli errori rilevati."

, "Allowed Contexts"
: "Contesti Ammessi"

, "Context"
: "Contesto"

, "Account Rights"
: "Permessi Account"

, "View"
: "Visualizza"

, "Use"
: "Utilizzo"

, "Tag Name"
: "Nome Tag"

, "Color"
: "Colore"

, "Transferring {0}..."
: "Trasferimento {0}..."

, "Tag"
: "Tag"

, "Add New Tag"
: "Aggiungi nuovo Tag"

, "Edit Tag \"{0}\""
: "Modifica Tag \"{0}\""

, "Do you really want to delete the selected tags?"
: "Vuoi veramente cancellare i tags selezionati?"

, "Deleting tag(s)..."
: "Cancellazione tag(s)..."

, "Add Tag"
: "Aggiungi Tag"

, "Edit Tag"
: "Modifica Tag"

, "Delete Tag"
: "Cancella Tag"

, "Displaying tags {0} - {1} of {2}"
: "Visualizzazione tags {0} - {1} di {2}"

, "No tags to display"
: "Nessun Tags da visualizzare"

, "Usage:&#160;"
: "Utilizzo:&#160;"

, "Updating Memberships"
: "Aggiornamento Appartenenze"

, "Could not save role."
: "Impossibile salvare ruolo."

, "Deleting role..."
: "Cancellazione ruolo..."

, "Some error occurred while trying to delete the role."
: "Si sono verificati alcuni errori durante il tentativo di cancellazione del ruolo."

, "Rights"
: "Permessi"

, "Members"
: "Membri"

, "Role Name"
: "Nome Ruolo"

, "Role"
: "Ruolo"

, "Add New Role"
: "Aggiungi Nuovo Ruolo"

, "Edit Role \"{0}\""
: "Modifica Ruolo \"{0}\""

, "Do you really want to delete the selected roles?"
: "Vuoi veramente cancellare il ruolo selezionato?"

, "Deleting role(s)..."
: "Cancellazione ruolo(i)..."

, "Add Role"
: "Aggiungi Ruolo"

, "Edit Role"
: "Modifica Ruolo"

, "Delete Role"
: "Cancella Ruolo"

, "Displaying roles {0} - {1} of {2}"
: "Visualizzazione ruoli {0} - {1} di {2}"

, "No roles to display"
: "Nessun ruolo da visualizzare"

, "Access Log, Access Logs"
: [
  "Registro Accessi"
 ,"Registri Accessi"

]
, "Groups"
: "Gruppi"

, "Applications"
: "Applicazioni"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: "Dominio non ammesso. Verificare la configurazione del dominio SMTP."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Le password non corrispondono"

, "Passwords match!"
: "Le password corrispondono!"

, "Primary group"
: "Gruppo Primario"

, "Unix"
: "Unix"

, "Home Directory"
: "Directory Home"

, "Login Shell"
: "Struttura Login"

, "Windows"
: "Windows"

, "Home Drive"
: "Drive Home"

, "Login Time"
: "Ora Accesso"

, "never logged in"
: "Accesso mai effettuato"

, "Home Path"
: "Percorso Home"

, "Logout Time"
: "Ora Disconnessione"

, "never logged off"
: "mai disconnesso"

, "Profile Path"
: "Percorso Profilo"

, "Password Last Set"
: "Ultima impostazione password"

, "never"
: "mai"

, "Logon Script"
: "Script di accesso"

, "Password Can Change"
: "Puo cambiare la password"

, "not set"
: "non impostato"

, "Password Must Change"
: "Modifica Obbligatoria Password "

, "Kick Off Time"
: "Ora d'inizio"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "Quota non impostata"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Dimensione corrente Casella postale"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Dimensione attuale Sieve"

, "Information"
: "Informazione"

, "Last Login"
: "Ultimo Accesso"

, "Domain not allowed"
: "Dominio Non Ammesso"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Aggiungi un indirizzo alias..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: "Inoltro a sé"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Inoltro Unicamente"

, "Password confirmation"
: "Conferma password"

, "Repeat password"
: "Ripeti Password"

, "Ok"
: "Ok"

, "Account"
: "Account"

, "First name"
: "nome"

, "Last name"
: "Cognome"

, "Login name"
: "Nome login"

, "Password"
: "Password"

, "OpenID"
: "OpenID"

, "enabled"
: "abilitato"

, "disabled"
: "disabilitato"

, "expired"
: "scaduto"

, "blocked"
: "bloccato"

, "Invalid Status"
: "Stato non valido"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Lo stato bloccato è valido solo se l'utente ha tentato di accedere diverse volte con una password errata. Non è possibile impostare questo stato qui."

, "Expires"
: "Scaduti"

, "Visibility"
: "Visibilità"

, "Display in addressbook"
: "Visualizza in Rubrica"

, "Hide from addressbook"
: "Nascondi dalla rubrica"

, "Saved in Addressbook"
: "Salvato in Rubrica"

, "Last login at"
: "Ultimo accesso al"

, "don't know"
: "non lo so"

, "Last login from"
: "Ultimo accesso da"

, "Password set"
: "Imposta password"

, "User groups"
: "Gruppi Utente"

, "User roles"
: "Ruoli Utente"

, "Fileserver"
: "Fileserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Utente"
 ,"Utenti"

]
, "Users"
: "Utenti"

, "Samba User, Samba Users"
: [
  "Utente Samba"
 ,"Utenti Samba"

]
, "Email User, Email Users"
: [
  "Utente Email"
 ,"Utenti Email"

]
, "Enable Account"
: "Attiva Account"

, "Disable Account"
: "Disattiva Account"

, "Reset Password"
: "Ripristina Password"

, "Reset Pin"
: ""

, "Display name"
: "Visualizza nome"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Password cambiata"

, "Set new password"
: "Imposta nuova password"

, "Please enter the new password:"
: "Si prega di inserire la nuova password:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Nome Gruppo"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Membri del gruppo"

, "personal"
: "personale"

, "shared"
: "condiviso"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Nota per il proprietario"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "Contenitore"
 ,"Contenitori"

]
, "Container Name"
: "Nome Contenitore"

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Computer"
 ,"Computers"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Ruoli"

, "Containers"
: "Contenitori"

, "Shared Tags"
: "Tags Condivisi"

, "Customfields"
: "campi personalizzati"

, "Computers"
: "Computers"

, "Server Information"
: "Informazioni Server"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Amministratore"

, "Refresh"
: "Aggiorna"

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "Indirizzo IP"

, "Client Type"
: "Tipo Cliente"

, "Session ID"
: "ID Sessione"

, "Login Name"
: "Nome login"

, "Result"
: "Risultato"

, "user blocked"
: "Utente Bloccato"

, "password expired"
: "password scaduta"

, "user disabled"
: "utente disabilitato"

, "invalid password"
: "Password non valida"

, "ambiguous username"
: "nome utente ambiguo"

, "user not found"
: "utente non trovato"

, "failure"
: "Errore"

, "success"
: "Successo"

, "Default IMAP user settings"
: "Impostazioni Utente IMAP Predefinito "

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Il tuo contenotore è stato modificato."

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Il tuo contenotore è stato modificato da %1$s %2$sNota: %3$s"

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""















































, "Application"
: "Applicazione"

, "Group"
: "Gruppo"

, "Customfield"
: "campo personalizzato"

, "Config"
: ""

, "Access Log"
: "Registro Accessi"

, "User"
: "Utente"

, "Samba User"
: "Utente Samba"

, "Email User"
: "Utente Email"

, "Container"
: "Contenitore"

, "Computer"
: "Computer"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Admin/js/Admin-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""

]
, "Application, Applications"
: [
  "Applicazione"
 ,"Applicazioni"

]
, "User, Users"
: [
  "Utente"
 ,"Utenti"

]
, "Groups"
: "Gruppi"

, "Roles"
: "Ruoli"

, "Applications"
: "Applicazioni"

, "Containers"
: "Contenitori"

, "Shared Tags"
: "Tags Condivisi"

, "Customfields"
: "campi personalizzati"

, "Computers"
: "Computers"

, "Access Log, Access Logs"
: [
  "Registro Accessi"
 ,"Registri Accessi"

]
, "Log"
: ""

, "Server Information"
: "Informazioni Server"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Amministratore"

, "Refresh"
: "Aggiorna"

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: "Rubrica di default per i nuovi contatti e gruppi"

, "Computer Name"
: "Nome Computer"

, "Config, Configs"
: [
  ""
 ,""

]
, "Description"
: "Descrizione"

, "Name"
: "Nome"

, "Label"
: "Etichetta"

, "Value"
: "Valore"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Nome Gruppo"

, "Visibility"
: "Visibilità"

, "Display in addressbook"
: "Visualizza in Rubrica"

, "Hide from addressbook"
: "Nascondi dalla rubrica"

, "Saved in Addressbook"
: "Salvato in Rubrica"

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Membri del gruppo"

, "Domain is not allowed. Check your SMTP domain configuration."
: "Dominio non ammesso. Verificare la configurazione del dominio SMTP."

, "Confirm"
: "Conferma"

, "Do you really want to delete the selected tags?"
: "Vuoi veramente cancellare i tags selezionati?"

, "Deleting tag(s)..."
: "Cancellazione tag(s)..."

, "Add Tag"
: "Aggiungi Tag"

, "Edit Tag"
: "Modifica Tag"

, "Delete Tag"
: "Cancella Tag"

, "Search:"
: "Cerca:"

, "Displaying tags {0} - {1} of {2}"
: "Visualizzazione tags {0} - {1} di {2}"

, "No tags to display"
: "Nessun Tags da visualizzare"

, "ID"
: "ID"

, "Color"
: "Colore"

, "Usage:&#160;"
: "Utilizzo:&#160;"

, "Do you really want to delete the selected roles?"
: "Vuoi veramente cancellare il ruolo selezionato?"

, "Deleting role(s)..."
: "Cancellazione ruolo(i)..."

, "Failed"
: "Fallita"

, "Some error occurred while trying to delete the role."
: "Si sono verificati alcuni errori durante il tentativo di cancellazione del ruolo."

, "Add Role"
: "Aggiungi Ruolo"

, "Edit Role"
: "Modifica Ruolo"

, "Delete Role"
: "Cancella Ruolo"

, "Displaying roles {0} - {1} of {2}"
: "Visualizzazione ruoli {0} - {1} di {2}"

, "No roles to display"
: "Nessun ruolo da visualizzare"

, "Container Name"
: "Nome Contenitore"

, "Type"
: "Tipo"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Contenitore"
 ,"Contenitori"

]
, "Model"
: "Modello"

, "personal"
: "personale"

, "shared"
: "condiviso"

, "Order"
: "Ordine"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Nota per il proprietario"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Vuoi veramente cancellare il gruppo selezionato?"

, "Deleting group(s)..."
: "Cancellazione gruppo(i)..."

, "Some error occurred while trying to delete the group."
: "Si sono verificati alcuni errori durante il tentativo di cancellazione del gruppo."

, "Add Group"
: "Aggiungi Gruppo"

, "Edit Group"
: "Modifica Gruppo"

, "Delete Group"
: "Cancella Gruppo"

, "Displaying groups {0} - {1} of {2}"
: "Visualizzazione gruppi {0} - {1} di {2}"

, "No groups to display"
: "Nessun gruppo da visualizzare"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "Indirizzo IP"

, "Login Time"
: "Ora Accesso"

, "Logout Time"
: "Ora Disconnessione"

, "Client Type"
: "Tipo Cliente"

, "Session ID"
: "ID Sessione"

, "Login Name"
: "Nome login"

, "Result"
: "Risultato"

, "User Agent"
: ""

, "user blocked"
: "Utente Bloccato"

, "password expired"
: "password scaduta"

, "user disabled"
: "utente disabilitato"

, "invalid password"
: "Password non valida"

, "ambiguous username"
: "nome utente ambiguo"

, "user not found"
: "utente non trovato"

, "failure"
: "Errore"

, "success"
: "Successo"

, "Customfield, Customfields"
: [
  "campo personalizzato"
 ,"campi personalizzati"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Errori"

, "Please configure store for this field type"
: "Si prega di configurare la memorizzazione per questo tipo di campo"

, "Record Class"
: "Record Classe"

, "Given record class not found"
: "Record classe non trovato"

, "Cancel"
: "Cancella"

, "OK"
: "OK"

, "Configure store"
: "Configurazione Memorizzazione"

, "Custom field definition"
: "definizione di campo personalizzato"

, "Text"
: "Testo"

, "Textarea"
: ""

, "Number"
: "Numero"

, "Date"
: "Data"

, "DateTime"
: "Data e Ora"

, "Time"
: "Ora"

, "Boolean"
: "Booleano"

, "Search Combo"
: "Ricerca combinata"

, "Key Field"
: "Campo Chiave"

, "Record"
: "Dato"

, "Record List"
: ""

, "Length"
: "Lunghezza"

, "Required"
: "Richiesto"

, "Custom field additional properties"
: "Proprietà dei campi personalizzati aggiuntivi"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Gruppo"
 ,"Gruppi"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: "Campo personalizzato già esistente. Scegli un altro nome."

, "Enable Account"
: "Attiva Account"

, "Disable Account"
: "Disattiva Account"

, "Reset Password"
: "Ripristina Password"

, "Status"
: "Stato"

, "Display name"
: "Visualizza nome"

, "Login name"
: "Nome login"

, "Last name"
: "Cognome"

, "First name"
: "nome"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Ultimo accesso al"

, "Last login from"
: "Ultimo accesso da"

, "Password Must Change"
: "Modifica Obbligatoria Password "

, "Password changed"
: "Password cambiata"

, "Expires"
: "Scaduti"

, "Set new password"
: "Imposta nuova password"

, "Please enter the new password:"
: "Si prega di inserire la nuova password:"

, "Users"
: "Utenti"

, "Samba User, Samba Users"
: [
  "Utente Samba"
 ,"Utenti Samba"

]
, "Email User, Email Users"
: [
  "Utente Email"
 ,"Utenti Email"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Le password non corrispondono"

, "Passwords match!"
: "Le password corrispondono!"

, "Primary group"
: "Gruppo Primario"

, "Unix"
: "Unix"

, "Home Directory"
: "Directory Home"

, "Login Shell"
: "Struttura Login"

, "Windows"
: "Windows"

, "Home Drive"
: "Drive Home"

, "never logged in"
: "Accesso mai effettuato"

, "Home Path"
: "Percorso Home"

, "never logged off"
: "mai disconnesso"

, "Profile Path"
: "Percorso Profilo"

, "Password Last Set"
: "Ultima impostazione password"

, "never"
: "mai"

, "Logon Script"
: "Script di accesso"

, "Password Can Change"
: "Puo cambiare la password"

, "not set"
: "non impostato"

, "Kick Off Time"
: "Ora d'inizio"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "Quota non impostata"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Dimensione corrente Casella postale"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Dimensione attuale Sieve"

, "Information"
: "Informazione"

, "Last Login"
: "Ultimo Accesso"

, "Forward Only"
: "Inoltro Unicamente"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Aggiungi un indirizzo alias..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: "Dominio Non Ammesso"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: "Inoltro a sé"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Conferma password"

, "Repeat password"
: "Ripeti Password"

, "Ok"
: "Ok"

, "Account"
: "Account"

, "Password"
: "Password"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "abilitato"

, "disabled"
: "disabilitato"

, "expired"
: "scaduto"

, "blocked"
: "bloccato"

, "Invalid Status"
: "Stato non valido"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Lo stato bloccato è valido solo se l'utente ha tentato di accedere diverse volte con una password errata. Non è possibile impostare questo stato qui."

, "don't know"
: "non lo so"

, "Password set"
: "Imposta password"

, "User groups"
: "Gruppi Utente"

, "User roles"
: "Ruoli Utente"

, "Fileserver"
: "Fileserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "Computer"
 ,"Computers"

]
, "Please wait"
: "Attendi"

, "Updating Memberships"
: "Aggiornamento Appartenenze"

, "Could not save role."
: "Impossibile salvare ruolo."

, "Please fix the errors noted."
: "Si prega di correggere gli errori rilevati."

, "Deleting role..."
: "Cancellazione ruolo..."

, "Rights"
: "Permessi"

, "Members"
: "Membri"

, "Role Name"
: "Nome Ruolo"

, "Transferring {0}..."
: "Trasferimento {0}..."

, "Role"
: "Ruolo"

, "Add New Role"
: "Aggiungi Nuovo Ruolo"

, "Edit Role \"{0}\""
: "Modifica Ruolo \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Aggiornamento Tag"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Contesti Ammessi"

, "Context"
: "Contesto"

, "Account Rights"
: "Permessi Account"

, "View"
: "Visualizza"

, "Use"
: "Utilizzo"

, "Tag Name"
: "Nome Tag"

, "Tag"
: "Tag"

, "Add New Tag"
: "Aggiungi nuovo Tag"

, "Edit Tag \"{0}\""
: "Modifica Tag \"{0}\""

, "Enable Application"
: "Attiva Applicazione"

, "Disable Application"
: "Disattiva Applicazione"

, "Settings"
: "Impostazioni"

, "{0} Settings"
: "{0} Impostazioni"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Visualizza applicazione {0} - {1} di {2}"

, "No applications to display"
: "Nessuna applicazione da visualizzare"

, "Version"
: "Versione"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "Impostazioni Utente IMAP Predefinito "

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Il tuo contenotore è stato modificato."

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Il tuo contenotore è stato modificato da %1$s %2$sNota: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""












































, "ImportExportDefinition"
: ""

, "Application"
: "Applicazione"

, "User"
: "Utente"

, "Access Log"
: "Registro Accessi"

, "Config"
: ""

, "Container"
: "Contenitore"

, "Customfield"
: "campo personalizzato"

, "Group"
: "Gruppo"

, "Samba User"
: "Utente Samba"

, "Email User"
: "Utente Email"

, "Computer"
: "Computer"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
